==> ant-design-vue-3.2.20.jar: META-INF/resources/webjars/ant-design-vue/3.2.20/lib/vc-steps/Steps.d.ts <==
export declare type Status = 'error' | 'process' | 'finish' | 'wait';
export declare type StepIconRender = (info: {
    index: number;
    status: Status;
    title: any;
    description: any;
    node: any;
}) => any;
export declare type ProgressDotRender = (info: {
    iconDot: any;
    index: number;
    status: Status;
    title: any;
    description: any;
}) => any;
declare const _default: import("vue").DefineComponent<{
    type: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    iconPrefix: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    direction: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    labelPlacement: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    status: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    size: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    progressDot: import("vue-types").VueTypeDef<any> & {
        default: any;
    };
    initial: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    current: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    icons: import("vue-types").VueTypeLooseShape<{
        finish: any;
        error: any;
    }>;
    stepIcon: FunctionConstructor;
}, () => JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, "change"[], "change", import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    type: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    iconPrefix: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    direction: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    labelPlacement: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    status: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    size: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    progressDot: import("vue-types").VueTypeDef<any> & {
        default: any;
    };
    initial: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    current: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    icons: import("vue-types").VueTypeLooseShape<{
        finish: any;
        error: any;
    }>;
    stepIcon: FunctionConstructor;
}>> & {
    onChange?: (...args: any[]) => any;
}, {
    initial: number;
    prefixCls: string;
    size: string;
    direction: string;
    current: number;
    type: string;
    status: string;
    progressDot: any;
    iconPrefix: string;
    labelPlacement: string;
}>;
export default _default;

==> ant-design-vue-4.0.0.jar: META-INF/resources/webjars/ant-design-vue/4.0.0/lib/vc-steps/Steps.d.ts <==
import type { VueNode } from '../_util/type';
import type { Status, StepIconRender } from './interface';
declare const _default: import("vue").DefineComponent<{
    type: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    iconPrefix: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    direction: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    labelPlacement: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    status: {
        type: import("vue").PropType<Status>;
        default: Status;
    };
    size: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    progressDot: import("vue-types").VueTypeDef<any> & {
        default: any;
    };
    initial: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    current: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    items: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    } & {
        default: () => unknown[];
    };
    icons: import("vue-types").VueTypeLooseShape<{
        finish: any;
        error: any;
    }>;
    stepIcon: {
        type: import("vue").PropType<StepIconRender>;
        default: StepIconRender;
    };
    isInline: import("vue-types").VueTypeValidableDef<boolean>;
    itemRender: {
        type: import("vue").PropType<(item: Record<string, any>, stepItem: VueNode) => VueNode>;
        default: (item: Record<string, any>, stepItem: VueNode) => VueNode;
    };
}, () => JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, "change"[], "change", import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    type: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    iconPrefix: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    direction: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    labelPlacement: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    status: {
        type: import("vue").PropType<Status>;
        default: Status;
    };
    size: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    progressDot: import("vue-types").VueTypeDef<any> & {
        default: any;
    };
    initial: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    current: import("vue-types").VueTypeValidableDef<number> & {
        default: number;
    } & {
        default: number;
    };
    items: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    } & {
        default: () => unknown[];
    };
    icons: import("vue-types").VueTypeLooseShape<{
        finish: any;
        error: any;
    }>;
    stepIcon: {
        type: import("vue").PropType<StepIconRender>;
        default: StepIconRender;
    };
    isInline: import("vue-types").VueTypeValidableDef<boolean>;
    itemRender: {
        type: import("vue").PropType<(item: Record<string, any>, stepItem: VueNode) => VueNode>;
        default: (item: Record<string, any>, stepItem: VueNode) => VueNode;
    };
}>> & {
    onChange?: (...args: any[]) => any;
}, {
    type: string;
    current: number;
    initial: number;
    size: string;
    direction: string;
    prefixCls: string;
    status: Status;
    items: unknown[];
    itemRender: (item: Record<string, any>, stepItem: VueNode) => VueNode;
    iconPrefix: string;
    progressDot: any;
    stepIcon: StepIconRender;
    labelPlacement: string;
}, {}>;
export default _default;
